<?php
include "configuration.php";
header('Content-Type: application/json');

$response = [
    'success' => false,
    'errors' => [],
    'data' => []
];

try {
    // Validate basic inputs
    $required_fields = ['service_required', 'name', 'phone'];
    foreach ($required_fields as $field) {
        if (empty($_POST[$field])) {
            $response['errors'][$field] = "$field is required";
        }
    }

    if (!empty($response['errors'])) {
        throw new Exception("Validation failed");
    }

    // Sanitize inputs
    $service = filter_var($_POST['service_required'], FILTER_SANITIZE_SPECIAL_CHARS);
    $name = filter_var($_POST['name'], FILTER_SANITIZE_SPECIAL_CHARS);
    $phone_country = filter_var($_POST['phone_country'] ?? '+91', FILTER_SANITIZE_SPECIAL_CHARS);
    $phone = filter_var($_POST['phone'], FILTER_SANITIZE_SPECIAL_CHARS);
    $message = filter_var($_POST['message'] ?? '', FILTER_SANITIZE_SPECIAL_CHARS);
    $email = null; // Since email isn't in the form, we'll set it as null

    // Setup upload directory
    $upload_dir = "uploads/" . date("Y-m-d") . "/";
    if (!is_dir($upload_dir) && !mkdir($upload_dir, 0777, true)) {
        throw new Exception("Failed to create upload directory");
    }

    $safe_name = preg_replace('/[^A-Za-z0-9]/', '', $name);
    $timestamp = date("YmdHis");
    $target_dir = $upload_dir . "{$safe_name}_{$timestamp}/";
    if (!mkdir($target_dir, 0777, true)) {
        throw new Exception("Failed to create client directory");
    }

    // File upload configuration
    $file_configs = [
        'income_tax' => ['bank_statements', 'pan_card', 'aadhaar_card'],
        'dsc' => ['pan_card', 'aadhaar_card', 'passport_photo', 'gst_certificate', 'partnership_deed'],
        // Add other services similarly
    ];

    $allowed_types = ['pdf', 'jpg', 'jpeg', 'png'];
    $max_size = 5 * 1024 * 1024; // 5MB

    // Process files
    $uploaded_files = [];
    $service_key = strtolower($service);
    if (isset($file_configs[$service_key]) && !empty($_FILES[$service_key]['name'])) {
        foreach ($_FILES[$service_key]['name'] as $field => $name) {
            if (empty($name) || $_FILES[$service_key]['error'][$field] === UPLOAD_ERR_NO_FILE) {
                continue;
            }

            if ($_FILES[$service_key]['error'][$field] !== UPLOAD_ERR_OK) {
                $response['errors'][$field] = "Upload error: " . $_FILES[$service_key]['error'][$field];
                continue;
            }

            $ext = strtolower(pathinfo($name, PATHINFO_EXTENSION));
            if (!in_array($ext, $allowed_types)) {
                $response['errors'][$field] = "Invalid file type. Allowed: " . implode(', ', $allowed_types);
                continue;
            }

            if ($_FILES[$service_key]['size'][$field] > $max_size) {
                $response['errors'][$field] = "File size exceeds 5MB limit";
                continue;
            }

            $target_file = $target_dir . "{$field}_{$timestamp}.{$ext}";
            if (move_uploaded_file($_FILES[$service_key]['tmp_name'][$field], $target_file)) {
                $uploaded_files[$field] = $target_file;
            } else {
                $response['errors'][$field] = "Failed to save file: " . error_get_last()['message'];
            }
        }
    }

    // Database insertion with corrected table structure
    $sql = "INSERT INTO client_data (service_required, timestamp, name, phone_country, phone, email) 
            VALUES (?, ?, ?, ?, ?, ?)";
    $stmt = $con->prepare($sql);
    $timestamp_str = date("Y-m-d H:i:s");
    $stmt->bind_param("ssssss", $service, $timestamp_str, $name, $phone_country, $phone, $email);
    
    if (!$stmt->execute()) {
        throw new Exception("Database error: " . $stmt->error);
    }

    $response['success'] = empty($response['errors']);
    $response['data'] = [
        'client_date_id' => $con->insert_id,
        'uploaded_files' => $uploaded_files
    ];

} catch (Exception $e) {
    $response['errors']['system'] = $e->getMessage();
    error_log("Client data save error: " . $e->getMessage());
}

echo json_encode($response);
$con->close();
?>